<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:tc="http://periapsis.org/tellico/"
                exclude-result-prefixes="tc"
                version="1.0">

<!--
   ===================================================================
   Tellico XSLT file - compact template for viewing entry data

   Copyright (C) 2003-2006 Robby Stephenson - robby@periapsis.org
   Copyright (C) 2007-2008 Norbert Nemec

   This XSLT stylesheet is designed to be used with the 'Tellico'
   application, which can be found at http://www.periapsis.org/tellico/
   
   This entry template is to be used with for bibliography collections.
   The design is inspired by the layout of article headers in the
   Physical Review journals but works equally for articles in general.

    This is a modified version of above described template.
    It tries to format the entries more in line with the german 
    bibliography rules for political science (at least my faculty).
      rieper
   ===================================================================
-->

<!-- import common templates -->
<!-- location depends on being installed correctly -->
<xsl:import href="../tellico-common.xsl"/>

<xsl:output method="html"/>

<xsl:param name="datadir"/> <!-- dir where Tellico data are located -->
<xsl:param name="imgdir"/> <!-- dir where field images are located -->
<xsl:param name="font"/> <!-- default KDE font family -->
<xsl:param name="fgcolor"/> <!-- default KDE foreground color -->
<xsl:param name="bgcolor"/> <!-- default KDE background color -->

<xsl:param name="collection-file"/> <!-- might have a link to parent collection -->

<xsl:key name="fieldsByName" match="tc:field" use="@name"/>
<xsl:key name="imagesById" match="tc:image" use="@id"/>

<xsl:variable name="endl">
<xsl:text>
</xsl:text>
</xsl:variable>

<xsl:template match="/">
 <xsl:apply-templates select="tc:tellico"/>
</xsl:template>

<!-- The default layout is pretty boring, but catches every field value in
     the entry. The title is in the top H1 element. -->
<xsl:template match="tc:tellico">
 <!-- This stylesheet is designed for Tellico document syntax version 9 -->
 <xsl:call-template name="syntax-version">
  <xsl:with-param name="this-version" select="'9'"/>
  <xsl:with-param name="data-version" select="@syntaxVersion"/>
 </xsl:call-template>

 <html>
  <head>
  <style type="text/css">
  body {
    margin: 0px;
    padding: 0px;
    font-family: <xsl:value-of select="$font"/>;
    color: <xsl:value-of select="$fgcolor"/>;
    background-color: <xsl:value-of select="$bgcolor"/>;
  }
  #content {
    padding-right: 160px;
  }
  #images {
    margin: 6px 5px 0px 5px;
    float: right;
    min-width: 150px;
  }
  div.img-shadow {
    float: left;
    background: url(<xsl:value-of select="concat($datadir,'shadowAlpha.png')"/>) no-repeat bottom right;
    margin: 10px 0 0 10px;
  }
  div.img-shadow img {
    display: block;
    position: relative;
    border: 1px solid #a9a9a9;
    margin: -6px 6px 6px -6px;
  }
  table {
    border-collapse: collapse;
    border-spacing: 0px;
  }
  th.fieldName {
    font-weight: bold;
    text-align: left;
    padding: 0px 4px 0px 2px;
    white-space: nowrap;
  }
  td.fieldValue {
    text-align: left;
    padding: 0px 10px 0px 2px;
  }
  td.column1 {
    text-align: left;
    padding: 0px;
  }
  td.column2 {
    font-style: italic;
    text-align: left;
    padding: 0px 10px;
  }
  p {
    margin-top: 0px;
    text-align: left;
  }
  ul {
    margin-top: 0px;
    margin-bottom: 0px;
    padding: 0px 0px 0px 20px;
  }
  img {
    border: 0px solid;
  }
  </style>
  <title>
   <xsl:value-of select="tc:collection/tc:entry[1]//tc:title[1]"/>
   <xsl:text> - </xsl:text>
   <xsl:value-of select="tc:collection/@title"/>
  </title>
  </head>
  <body>
   <xsl:apply-templates select="tc:collection[1]"/>
   <xsl:if test="$collection-file">
    <hr style="clear:left"/>
    <h4 style="text-align:center">
     <a href="{$collection-file}">&lt;&lt; <xsl:value-of select="tc:collection/@title"/></a>
    </h4>
   </xsl:if>
  </body>
 </html>
</xsl:template>

<xsl:template match="tc:collection">
 <xsl:apply-templates select="tc:entry[1]"/>
 <xsl:if test="tc:entry[1]/tc:amazon">
  <hr/>
  <p style="text-align:center">Data provided by <a href="{tc:entry[1]/tc:amazon}">Amazon.com</a></p>
 </xsl:if>
</xsl:template>

<xsl:template match="tc:entry">
 <xsl:variable name="entry" select="."/>
<p>
 <i>
<xsl:for-each select="$entry/tc:authors/*">
  <xsl:value-of select="."/>
     <xsl:choose>   
      <xsl:when test="position() + 1 = last()">
	<xsl:text> and </xsl:text>
      </xsl:when>
      <xsl:when test="position() = last()">
	<xsl:text></xsl:text>
      </xsl:when>
      <xsl:otherwise test="position() != last()">
	<xsl:text>, </xsl:text>
      </xsl:otherwise>
    </xsl:choose>
</xsl:for-each>
</i>
<xsl:choose>
  <xsl:when test="$entry/tc:year[1]">
    <xsl:text> (</xsl:text>
    <xsl:value-of select="$entry/tc:year[1]"/>
    <xsl:text>): </xsl:text>
  </xsl:when>
  <xsl:otherwise>
    <xsl:text>: </xsl:text>
  </xsl:otherwise>
</xsl:choose>

<xsl:value-of select="$entry/tc:title[1]"/>
 <xsl:text>. </xsl:text>
<xsl:if test="$entry/tc:editors">
 <xsl:text> In: </xsl:text>
  <xsl:for-each select="$entry/tc:editors/*">
    <xsl:value-of select="."/>
      <xsl:choose>   
	<xsl:when test="position() + 1 = last()">
	  <xsl:text> and </xsl:text>
	</xsl:when>
	<xsl:when test="position() = last()">
	  <xsl:text>: </xsl:text>
	</xsl:when>
	<xsl:otherwise test="position() != last()">
	  <xsl:text>, </xsl:text>
	</xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>
  <xsl:value-of select="$entry/tc:booktitle"/> 
  <xsl:text>. </xsl:text>
</xsl:if>

<xsl:if test="$entry/tc:entry-type[1] = 'article'">
  <xsl:choose>
    <xsl:when test="$entry/tc:journal[1]">
      <xsl:value-of select="$entry/tc:journal[1]"/>
      <xsl:text>, </xsl:text>
    </xsl:when>
    <xsl:when test="$entry/tc:volume[1]">
      <xsl:value-of select="$entry/tc:volume[1]"/>
      <xsl:text>, </xsl:text>
    </xsl:when>
    <xsl:when test="$entry/tc:pages[1]">
      <xsl:value-of select="$entry/tc:pages[1]"/>
      <xsl:text>. </xsl:text>
    </xsl:when>
  </xsl:choose>
</xsl:if>

<xsl:if test="$entry/tc:address">
  <xsl:value-of select="$entry/tc:address"/> 
    <xsl:text>: </xsl:text>
</xsl:if>

<xsl:if test="$entry/tc:publisher">
  <xsl:value-of select="$entry/tc:publisher"/> 
  <xsl:text>. </xsl:text>
</xsl:if>

</p>
 <p style="text-align:justify;text-indent:1em;margin-left:1cm;margin-right:1cm;font-family:serif;font-size:80%;">
  <xsl:value-of select="$entry/tc:abstract[1]" disable-output-escaping="yes"/>
 </p>
 <table width="100%" style="font-size:70%"><tbody><tr>
  <xsl:if test="$entry/tc:doi">
   <xsl:variable name="doi" select="$entry/tc:doi"/>
   <td align="center"><a href="http://dx.doi.org/{$doi}">doi:<xsl:value-of select="$entry/tc:doi[1]"/></a></td>
  </xsl:if>
  <xsl:if test="$entry/tc:arxiv">
   <xsl:variable name="arxiv" select="$entry/tc:arxiv"/>
   <td align="center"><a href="http://arxiv.org/abs/{$arxiv}">arXiv:<xsl:value-of select="$entry/tc:arxiv[1]"/></a></td>
  </xsl:if>
  <xsl:if test="$entry/tc:url">
   <xsl:variable name="url" select="$entry/tc:url"/>
   <td align="center"><a href="{$url}"><xsl:value-of select="$entry/tc:url[1]"/></a></td>
  </xsl:if>
  <xsl:variable name="local" select="$entry/tc:local"/>
  <td align="center"><a href="{$local}" style="color:green"><xsl:value-of select="$entry/tc:local[1]"/></a></td>
 </tr></tbody></table>
 <hr/>
 <p style="text-align:left;margin-left:5mm;margin-right:5mm;font-family:monospace;color:#008800;font-weight:bold;">
  <xsl:for-each select="$entry/tc:keywords/*">
   <span style="text-decoration:underline;"><xsl:value-of select="."/></span>
   <xsl:if test="position() != last()">
    <xsl:text>, </xsl:text>
   </xsl:if>
  </xsl:for-each>
 </p>
 <p style="text-align:left;margin-left:5mm;margin-right:5mm;font-family:monospace;color:#880000;font-weight:bold;">
  <xsl:value-of select="$entry/tc:comment[1]" disable-output-escaping="yes"/>
 </p>
 <hr/>


  <!-- all the data is in the content block -->
 <div id="content">

  <!-- now for all the rest of the data -->
  <!-- iterate over the categories, but skip images -->
  <table>
   <tbody>
    <xsl:for-each select="../tc:fields/tc:field[@type!=10]">
     <xsl:variable name="field" select="."/>

     <xsl:choose>
     <xsl:when test="$entry/tc:entry-type[1] = 'article' and $field/@name = 'journal'"/>
     <xsl:when test="$entry/tc:entry-type[1] = 'article' and $field/@name = 'volume'"/>
     <xsl:when test="$entry/tc:entry-type[1] = 'article' and $field/@name = 'pages'"/>
     <xsl:when test="$entry/tc:entry-type[1] = 'article' and $field/@name = 'year'"/>
     <xsl:when test="$field/@name = 'title'"/>
     <xsl:when test="$field/@name = 'author'"/>
     <xsl:when test="$field/@name = 'abstract'"/>
     <xsl:when test="$field/@name = 'web'"/>
     <xsl:when test="$field/@name = 'arxiv'"/>
     <xsl:when test="$field/@name = 'local'"/>
     <xsl:when test="$field/@name = 'keyword'"/>
     <xsl:when test="$field/@name = 'comment'"/>
     <xsl:otherwise>
     <xsl:if test="$entry//*[local-name(.) = $field/@name]">
      <tr>
      <th class="fieldName" valign="top">
       <xsl:value-of select="@title"/>
       <xsl:text>:</xsl:text>
      </th>

      <td class="fieldValue">
       <!-- ok, big xsl:choose loop for field type -->
       <xsl:choose>

        <!-- paragraphs are field type 2 -->
        <xsl:when test="@type = 2">
         <p>
          <xsl:value-of select="$entry/*[local-name(.) = $field/@name]" disable-output-escaping="yes"/>
         </p>
        </xsl:when>

        <!-- tables are field type 8 -->
        <!-- ok to put category name inside div instead of table here -->
        <xsl:when test="@type = 8">
         <!-- look at number of columns -->
         <xsl:choose>
          <xsl:when test="$field/tc:prop[@name = 'columns'] &gt; 1">
           <table>
            <tbody>
             <xsl:for-each select="$entry//*[local-name(.) = $field/@name]">
              <tr>
               <xsl:for-each select="tc:column">
                <xsl:choose>
                 <xsl:when test="position() = 1">
                  <td class="column1">
                   <xsl:value-of select="."/>
                   <xsl:text>&#160;</xsl:text>
                  </td>
                 </xsl:when>
                 <xsl:otherwise>
                  <td class="column2">
                   <xsl:value-of select="."/>
                   <xsl:text>&#160;</xsl:text>
                  </td>
                 </xsl:otherwise>
                </xsl:choose>
               </xsl:for-each>
              </tr>
             </xsl:for-each>
            </tbody>
           </table>
          </xsl:when>
          <xsl:otherwise>
           <ul>
            <xsl:for-each select="$entry//*[local-name(.) = $field/@name]">
             <li>
              <xsl:value-of select="."/>
             </li>
            </xsl:for-each>
           </ul>
          </xsl:otherwise>
         </xsl:choose>
        </xsl:when>

        <xsl:otherwise>
         <xsl:call-template name="simple-field-value">
          <xsl:with-param name="entry" select="$entry"/>
          <xsl:with-param name="field" select="$field/@name"/>
         </xsl:call-template>
        </xsl:otherwise>

       </xsl:choose>
      </td>
     </tr>
    </xsl:if>
    </xsl:otherwise>
    </xsl:choose>
   </xsl:for-each>
  </tbody>
 </table>
 </div>
</xsl:template>

</xsl:stylesheet>
